import { ViewConfig } from '../types';
import { TsEmbed } from './ts-embed';
/**
 * Configuration for bodyless conversation options.
 * @group Embed components
 */
export interface BodylessConversationViewConfig extends ViewConfig {
    /**
     * The ID of the worksheet to use for the conversation.
     */
    worksheetId: string;
}
interface ConversationMessageViewConfig extends BodylessConversationViewConfig {
    sessionId: string;
    genNo: number;
    acSessionId: string;
    acGenNo: number;
}
declare class ConversationMessage extends TsEmbed {
    protected viewConfig: ConversationMessageViewConfig;
    constructor(container: HTMLElement, viewConfig: ConversationMessageViewConfig);
    getIframeSrc(): string;
    render(): Promise<ConversationMessage>;
}
/**
 * Create a conversation embed, which can be integrated inside
 * chatbots or other conversational interfaces.
 * @example
 * ```js
 * import { BodylessConversation } from '@thoughtspot/visual-embed-sdk';
 *
 * const conversation = new BodylessConversation({
 *  worksheetId: 'worksheetId',
 * });
 *
 * const { container, error } = await conversation.sendMessage('show me sales by region');
 *
 * // append the container to the DOM
 * document.body.appendChild(container); // or to any other element
 * ```
 * @group Embed components
 * @version SDK: 1.33.1 | ThoughtSpot: 10.5.0.cl
 */
export declare class BodylessConversation {
    private viewConfig;
    private conversationService;
    constructor(viewConfig: BodylessConversationViewConfig);
    sendMessage(userMessage: string): Promise<{
        error: any;
        container?: undefined;
        viz?: undefined;
    } | {
        container: HTMLDivElement;
        viz: ConversationMessage;
        error?: undefined;
    }>;
}
export {};
//# sourceMappingURL=bodyless-conversation.d.ts.map