import { ViewConfig } from '../types';
import { TsEmbed } from './ts-embed';
/**
 * Configuration for search options
 */
export interface SearchOptions {
    /**
     * The query string to pass to start the Conversation.
     */
    searchQuery: string;
}
/**
 * The configuration for the embedded conversationEmbed options.
 * @group Embed components
 */
export interface ConversationViewConfig extends ViewConfig {
    /**
     * The ID of the worksheet to use for the conversation.
     */
    worksheetId: string;
    /**
     * Ability to pass a starting search query to the conversation.
     */
    searchOptions?: SearchOptions;
    /**
     * disableSourceSelection : Disables data source selection
     * but still display the selected data source.
     * @example
     * ```js
     * const embed = new ConversationEmbed('#tsEmbed', {
     *    ... // other options
     *    disableSourceSelection : true,
     * })
     * ```
     * @version SDK: 1.36.0 | Thoughtspot: 10.6.0.cl
     */
    disableSourceSelection?: boolean;
    /**
     * hideSourceSelection : Hide data source selection
     * @example
     * ```js
     * const embed = new ConversationEmbed('#tsEmbed', {
     *    ... // other options
     *    hideSourceSelection : true,
     * })
     * ```
     * @version SDK: 1.36.0 | Thoughtspot: 10.6.0.cl
     */
    hideSourceSelection?: boolean;
    /**
     * Flag to control Data panel experience
     * @default false
     * @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.4.0.cl
     * @example
     * ```js
     * const embed = new AppEmbed('#tsEmbed', {
     *    ... // other options
     *    dataPanelV2: true,
     * })
     * ```
     */
    dataPanelV2?: boolean;
    /**
     * showSpotterLimitations : show limitation text
     * of the spotter underneath the chat input.
     * default is false.
     * @example
     * ```js
     * const embed = new ConversationEmbed('#tsEmbed', {
     *    ... // other options
     *    showSpotterLimitations : true,
     * })
     * ```
     * @version SDK: 1.36.0 | Thoughtspot: 10.5.0.cl
     */
    showSpotterLimitations?: boolean;
    /**
     * hideSampleQuestions : Hide sample questions on
     * the initial screen of the conversation.
     * @example
     * ```js
     * const embed = new ConversationEmbed('#tsEmbed', {
     *    ... // other options
     *    hideSampleQuestions : true,
     * })
     * ```
     * @version SDK: 1.36.0 | Thoughtspot: 10.6.0.cl
     */
    hideSampleQuestions?: boolean;
}
/**
 * Embed ThoughtSpot AI Conversation.
 * @group Embed components
 * @example
 * ```js
 * const conversation = new ConversationEmbed('#tsEmbed', {
 *   worksheetId: 'worksheetId',
 *   searchOptions: {
 *     searchQuery: 'searchQuery',
 *   },
 * });
 * conversation.render();
 * ```
 * @version SDK: 1.33.1 | ThoughtSpot: 10.5.0.cl
 */
export declare class ConversationEmbed extends TsEmbed {
    protected viewConfig: ConversationViewConfig;
    constructor(container: HTMLElement, viewConfig: ConversationViewConfig);
    getIframeSrc(): string;
    render(): Promise<ConversationEmbed>;
}
//# sourceMappingURL=conversation.d.ts.map